.. _bluegraph_core_ref:

`bluegraph.core` package
------------------------------

.. toctree::
   :hidden:

   ../modules/bluegraph_core_io
   ../packages/bluegraph_core_analyse
   ../packages/bluegraph_core_embed
